@@ -1,11 +1,11 @@
-from typing import Any
+from typing import Any, Optional
 
 import click
 
 from .cli_utils import is_verbose
 
 
-def secho(msg: Any, fg: str, bold: bool = True) -> None:
+def secho(msg: Any, fg: str, bold: bool = False) -> None:
     """Similar to click.secho"""
     if not isinstance(msg, str):
         msg = str(msg)
@@ -14,12 +14,12 @@ def secho(msg: Any, fg: str, bold: bool = True) -> None:
 
 def warning(msg: Any) -> None:
     """click.echo in a yellow color"""
-    secho(msg, "yellow")
+    secho(f"WARNING: {msg}", "yellow")
 
 
 def error(msg: Any) -> None:
     """click.echo in a red color"""
-    secho(msg, "red")
+    secho(f"ERROR: {msg}", "red")
 
 
 def info(msg: Any) -> None:
@@ -33,10 +33,12 @@ def debug(msg: Any) -> None:
         secho(msg, "white", bold=False)
 
 
-def prompt(text: str, hide_input: bool = False, fg: str = "cyan") -> Any:
+def prompt(
+    text: str, hide_input: bool = False, fg: str = "cyan", default: Any = None, type: Optional[click.ParamType] = None
+) -> Any:
     """Ask the user to enter a value, and return the result"""
     text = click.style(text, fg=fg, bold=True)
-    return click.prompt(text, hide_input=hide_input)
+    return click.prompt(text, hide_input=hide_input, default=default, type=type)
 
 
 def confirm(text: str, default: bool = True, fg: str = "cyan") -> bool:
